@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.4.9"
+    version = "1.5.0"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -109,7 +109,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         custom_keyword = self.get_option("custom_keyword", project)
         phones = self.get_option("phones", project)
 
-        issue_link = group.url
+        issue_link = group.get_absolute_url(params={"referrer": "dingtalknotify"})
         issue_link = issue_link.replace('https', 'http')
 
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
@@ -118,7 +118,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title if group.title else 'unknown'}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
-        payload = f"{payload} > 全部错误: {group} \n\n"
+        payload = f"{payload} > 全部报错: {group} \n\n"
 
         headers = {
             "Content-type": "application/json",
